
<img src="docs/images/amiga-by-clare.PNG" alt="drawing" style="width:400px;"/></img>

##

**A**nalysis of **Mi**crobial **G**rowth **A**ssays is a user-friendly program for analysis of high-throughput microbial growth assays using Gaussian Process regression. Users can interact with `AMiGA` via a command-line interface.

## Documentation

See [documentation](https://firasmidani.github.io/amiga) for tutorials, technical details, and examples.

## Installation

See [Installation](https://firasmidani.github.io/amiga/doc/installation.html) for instructions and requirements.

## License

This project is covered under the [GPL-3 license](https://www.gnu.org/licenses/gpl-3.0.en.html).

## Bugs/Feature Requests

Please post issues [here](https://github.com/firasmidani/amiga/issues).

## Manuscript and Citation

FS Midani, J Collins, and RA Britton.  
__AMiGA: software for automated analysis of microbial growth assays.__  
*mSystems* (2021). [https://doi.org/10.1128/mSystems.00508-21](https://doi.org/10.1128/mSystems.00508-21)  

To reproduce analysis and figures in the manuscript, see [Manuscript README](https://github.com/firasmidani/amiga/blob/master/examples/manuscript/README.md).

## Acknowledgements

This software was developed at the Baylor College of Medicine in Houston, Texas, and was supported by several grants from the National Institutes of Health including T32DK007664, R01AI123278, and U01AI124290. Logo for AMiGA was created by Clare Robertson.
